<?php

namespace SureCart\Licensing;

/**
 * The settings class.
 */
class Settings {
	/**
	 * SureCart\Licensing\Client
	 *
	 * @var object
	 */
	protected $client;

	/**
	 * Holds the option key
	 *
	 * @var string
	 */
	private $option_key;

	/**
	 * Holds the option name
	 *
	 * @var string
	 */
	private $name;

	/**
	 * Holds the menu arguments
	 *
	 * @var array
	 */
	private $menu_args;

	/**
	 * Create the pages.
	 *
	 * @param SureCart\Licensing\Client $client The client.
	 */
	public function __construct( Client $client ) {
		$this->client     = $client;
		$this->name       = strtolower( preg_replace( '/\s+/', '', $this->client->name ) );
		$this->option_key = $this->name . '_license_options';
	}

	/**
	 * Add the settings page.
	 *
	 * @param array $args Settings page args.
	 *
	 * @return void
	 */
	public function add_page( $args ) {
		// store menu args for proper menu creation.
		$this->menu_args = wp_parse_args(
			$args,
			array(
				'type'               => 'menu', // Can be: menu, options, submenu.
				'page_title'         => 'Manage License',
				'menu_title'         => 'Manage License',
				'capability'         => 'manage_options',
				'menu_slug'          => $this->client->slug . '-manage-license',
				'icon_url'           => '',
				'position'           => null,
				'activated_redirect' => null,
				'parent_slug'        => '',
			)
		);
		add_action( 'admin_menu', array( $this, 'admin_menu' ), 99 );
	}

	/**
	 * Form action URL
	 */
	private function form_action_url() {
		return apply_filters( 'surecart_client_license_form_action', '' );
	}

	/**
	 * Set the option key.
	 *
	 * If someone wants to override the default generated key.
	 *
	 * @param string $key The option key.
	 */
	public function set_option_key( $key ) {
		$this->option_key = $key;
		return $this;
	}

	/**
	 * Add the admin menu
	 *
	 * @return void
	 */
	public function admin_menu() {
		switch ( $this->menu_args['type'] ) {
			case 'menu':
				$this->create_menu_page();
				break;
			case 'submenu':
				$this->create_submenu_page();
				break;
			case 'options':
				$this->create_options_page();
				break;
		}
	}

	/**
	 * Add license menu page
	 */
	private function create_menu_page() {
		call_user_func(
			'add_menu_page',
			$this->menu_args['page_title'],
			$this->menu_args['menu_title'],
			$this->menu_args['capability'],
			$this->menu_args['menu_slug'],
			array( $this, 'settings_output' ),
			$this->menu_args['icon_url'],
			$this->menu_args['position']
		);
	}

	/**
	 * Add submenu page
	 */
	private function create_submenu_page() {
		call_user_func(
			'add_submenu_page',
			$this->menu_args['parent_slug'],
			$this->menu_args['page_title'],
			$this->menu_args['menu_title'],
			$this->menu_args['capability'],
			$this->menu_args['menu_slug'],
			array( $this, 'settings_output' ),
			$this->menu_args['position']
		);
	}

	/**
	 * Add submenu page
	 */
	private function create_options_page() {
		call_user_func(
			'add_options_page',
			$this->menu_args['page_title'],
			$this->menu_args['menu_title'],
			$this->menu_args['capability'],
			$this->menu_args['menu_slug'],
			array( $this, 'settings_output' ),
			$this->menu_args['position']
		);
	}

	/**
	 * Get all options
	 *
	 * @return array
	 */
	public function get_options() {
		return (array) get_option( $this->option_key, array() );
	}

	/**
	 * Clear out the options.
	 *
	 * @return bool
	 */
	public function clear_options() {
		return update_option( $this->option_key, array() );
	}

	/**
	 * Get a specific option
	 *
	 * @param string $name Option name.
	 *
	 * @return mixed
	 */
	public function get_option( $name ) {
		$options = $this->get_options();
		return isset( $options[ $name ] ) ? $options[ $name ] : null;
	}

	/**
	 * Set the option.
	 *
	 * @param string $name The option name.
	 * @param mixed  $value The option value.
	 *
	 * @return bool
	 */
	public function set_option( $name, $value ) {
		$options          = (array) $this->get_options();
		$options[ $name ] = $value;
		return update_option( $this->option_key, $options );
	}

	/**
	 * The settings page menu output.
	 *
	 * @return void
	 */
	public function settings_output() {
		$this->license_form_submit();

		$this->print_css();

		$activation = $this->get_activation();
		$action     = ! empty( $activation->id ) ? 'deactivate' : 'activate'
		?>

		<?php
		$active_tab = isset($_GET['tab']) ? sanitize_text_field($_GET['tab']) : 'text-elements';
		?>
		<div class="bc-body">
			<a href="https://brickscore.io//changelog" target="_blank" class="bc-sidebar__changelog-wrapper">
				<span class="bc-sidebar__changelog-title">Version <?php echo BRICKSCORE_VERSION ?></span>
				<img class="bc-sidebar__changelog-logo" src="https://brickscore.io/wp-content/uploads/2023/12/plugin-dashboard-changelog.png">
			</a>
			<div class="bc-sidebar">
				<div class="bc-sidebar__navigation">

					<div class="bc-sidebar__logo-wrapper">
						<img class="bc-sidebar__logo" src="https://brickscore.io/wp-content/uploads/2023/08/bricks2.png">
						<h2 class="bc-sidebar__logo-title">brickscore</h2>
					</div>

					<a href="admin.php?page=brickscore&tab=text-elements" class="bc-sidebar__nav-item-wrapper <?php echo $active_tab === 'text-elements' ? 'bc-sidebar__nav-item-wrapper-active' : ''; ?>">
						<img class="bc-sidebar__nav-item-image" src="https://brickscore.io/wp-content/uploads/2023/12/plugin-dashboard-text-elements.png">
						Text Elements
					</a>
					
					<a href="admin.php?page=brickscore&tab=button-elements" class="bc-sidebar__nav-item-wrapper <?php echo $active_tab === 'button-elements' ? 'bc-sidebar__nav-item-wrapper-active' : ''; ?>">
						<img class="bc-sidebar__nav-item-image" src="https://brickscore.io/wp-content/uploads/2023/12/plugin-dashboard-button-elements.png">
						Button Elements
					</a>

					<a href="admin.php?page=brickscore&tab=menu-elements" class="bc-sidebar__nav-item-wrapper <?php echo $active_tab === 'menu-elements' ? 'bc-sidebar__nav-item-wrapper-active' : ''; ?>">
						<img class="bc-sidebar__nav-item-image" src="https://brickscore.io/wp-content/uploads/2023/12/plugin-dashboard-menu-elements.png">
						Menu Elements
					</a>

					<a href="admin.php?page=brickscore&tab=core-elements" class="bc-sidebar__nav-item-wrapper <?php echo $active_tab === 'core-elements' ? 'bc-sidebar__nav-item-wrapper-active' : ''; ?>">
						<img class="bc-sidebar__nav-item-image" src="https://brickscore.io/wp-content/uploads/2023/12/plugin-dashboard-core-elements.png">
						Core Elements
					</a>

					<a href="admin.php?page=brickscore&tab=libraries" class="bc-sidebar__nav-item-wrapper <?php echo $active_tab === 'libraries' ? 'bc-sidebar__nav-item-wrapper-active' : ''; ?>">
						<img class="bc-sidebar__nav-item-image" src="https://brickscore.io/wp-content/uploads/2023/12/plugin-dashboard-libraries.png">
						Libraries
					</a>

					<div class="bc-sidebar__nav-item-separator"></div>

					<a href="admin.php?page=brickscore&tab=features" class="bc-sidebar__nav-item-wrapper <?php echo $active_tab === 'features' ? 'bc-sidebar__nav-item-wrapper-active' : ''; ?>">
						<img class="bc-sidebar__nav-item-image" src="https://brickscore.io/wp-content/uploads/2023/12/plugin-dashboard-features.png">
						Features
					</a>

					<div class="bc-sidebar__nav-item-separator"></div>

					<a href="admin.php?page=brickscore&tab=library" class="bc-sidebar__nav-item-wrapper <?php echo $active_tab === 'library' ? 'bc-sidebar__nav-item-wrapper-active' : ''; ?>">
						<img class="bc-sidebar__nav-item-image" src="https://brickscore.io/wp-content/uploads/2023/12/plugin-dashboard-library.png">
						Library
					</a>
				</div>

				<div class="bc-license">
					<?php settings_errors(); ?>

					<div class="<?php echo esc_attr( $this->name ) . '-form-container'; ?> wrapper-form-container">

						<form method="post" action="<?php echo esc_attr( $this->form_action_url() ); ?>">
							<input type="hidden" name="_action" value="<?php echo esc_attr( $action ); ?>">
							<input type="hidden" name="_nonce" value="<?php echo esc_attr( wp_create_nonce( $this->client->name ) ); ?>">
							<input type="hidden" name="activation_id" value="<?php echo esc_attr( $this->activation_id ); ?>">

							<div class="bc-form__wrapper">
								<?php if ( 'activate' === $action ) : ?> 
									<input placeholder="License" class="bc-form__input" type="password" autocomplete="off" name="license_key" id="license_key" value="<?php echo esc_attr( $this->license_key ); ?>" autofocus>
									<?php update_option('activate_brickscore', false); //Variable desactivar Brickscore?> 
								<?php else : ?>
									<div class="label-license-deactivate-state">This site is activated</div>
									<?php update_option('activate_brickscore', true); //Variable activar Brickscore?>
								<?php endif; ?>

								<?php if ( isset( $_GET['debug'] ) ) : // phpcs:ignore  ?>
									<label for="license_id"><?php echo esc_html( sprintf( $this->client->__( 'License ID', 'surecart' ), $this->client->name ) ); ?></label>
									<input class="widefat" type="text" autocomplete="off" name="license_id" id="license_id" value="<?php echo esc_attr( $this->license_id ); ?>" autofocus>

									<label for="activation_id"><?php echo esc_html( sprintf( $this->client->__( 'Activation ID', 'surecart' ), $this->client->name ) ); ?></label>
									<input class="widefat" type="text" autocomplete="off" name="activation_id" id="activation_id" value="<?php echo esc_attr( $this->activation_id ); ?>" autofocus>
								<?php endif; ?>

								<?php submit_button( 'activate' === $action ? $this->client->__( 'Activate' ) : $this->client->__( 'Deactivate' ) ); ?>
							</div>
						</form>
					</div>
				</div>
			</div>

			<?php if ($active_tab === 'text-elements') { ?>
			<?php require_once __DIR__ . '/../../manage-text-elements.php'; ?>

			<form class="bc-settings" method="post">
				<div class="bc-settings__wrapper">
					<div class="bc-settings__title-save-wrapper">
						<div class="bc-settings__title-wrapper">
							<img class="bc-settings__icon--texts" src="https://brickscore.io/wp-content/uploads/2023/12/plugin-dashboard-text-elements.png">
							<span class="bc-settings__title">Text elements</span>
						</div>

						<div class="bc-wrapper-toggle-all-save-submit">
							<div class="element-setting-wrapper">
								<span class="heading-element-setting">Toggle All</span>
								<input type="checkbox" id="toggle-all" name="panelbctogglealltexts" value="true" <?php checked('true', $bc_toggle_all_texts_enable); ?>/>
								<label for="toggle-all"></label>
							</div>

							<div class="bc-settings__save">
								<button type="submit" class="panel-bc-submit">Save changes</button>
							</div>
						</div>
					</div>

					<div class="wrapper-element-setting-wrapper">
						<input type="hidden" name="bc-dashboard-form"/>
						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Counter</span>
							<input type="checkbox" id="panel-bc-counter" name="panelbccounter" value="true" <?php checked('true', $bc_counter_enable); ?>/>
							<label for="panel-bc-counter"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Exchange Title</span>
							<input type="checkbox" id="panel-bc-exchange-title" name="panelbcexchangetitle" value="true" <?php checked('true', $bc_exchange_title_enable); ?>/>
							<label for="panel-bc-exchange-title"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Mask Hover</span>
							<input type="checkbox" id="panel-bc-mask-hover" name="panelbcmaskhover" value="true" <?php checked('true', $bc_mask_hover_enable); ?>/>
							<label for="panel-bc-mask-hover"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Unfold Reveal</span>
							<input type="checkbox" id="panel-bc-unfold-reveal" name="panelbcunfoldreveal" value="true" <?php checked('true', $bc_unfold_reveal_enable); ?>/>
							<label for="panel-bc-unfold-reveal"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Decode Reveal</span>
							<input type="checkbox" id="panel-bc-decode-reveal" name="panelbcdecodereveal" value="true" <?php checked('true', $bc_decode_reveal_enable); ?>/>
							<label for="panel-bc-decode-reveal"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Decode Hover</span>
							<input type="checkbox" id="panel-bc-decode-hover" name="panelbcdecodehover" value="true" <?php checked('true', $bc_decode_hover_enable); ?>/>
							<label for="panel-bc-decode-hover"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Blended Hover</span>
							<input type="checkbox" id="panel-bc-blended-title" name="panelbcblendedtitle" value="true" <?php checked('true', $bc_blended_title_enable); ?>/>
							<label for="panel-bc-blended-title"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">3D Swap Hover</span>
							<input type="checkbox" id="panel-bc-3dswap-title" name="panelbc3dswaptitle" value="true" <?php checked('true', $bc_3d_swap_title_enable); ?>/>
							<label for="panel-bc-3dswap-title"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Scroll Reading</span>
							<input type="checkbox" id="panel-bc-scroll-reading" name="panelbcscrollreading" value="true" <?php checked('true', $bc_scroll_reading_enable); ?>/>
							<label for="panel-bc-scroll-reading"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Twist Reveal</span>
							<input type="checkbox" id="panel-bc-twist-title" name="panelbctwisttitle" value="true" <?php checked('true', $bc_twist_title_enable); ?>/>
							<label for="panel-bc-twist-title"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Letter Launcher</span>
							<input type="checkbox" id="panel-bc-letter-launcher" name="panelbcletterlauncher" value="true" <?php checked('true', $bc_letter_launcher_enable); ?>/>
							<label for="panel-bc-letter-launcher"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Blade Reveal</span>
							<input type="checkbox" id="panel-bc-blade-title" name="panelbcbladetitle" value="true" <?php checked('true', $bc_blade_title_enable); ?>/>
							<label for="panel-bc-blade-title"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Circular Title</span>
							<input type="checkbox" id="panel-bc-circular-title" name="panelbccirculartitle" value="true" <?php checked('true', $bc_circular_title_enable); ?>/>
							<label for="panel-bc-circular-title"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Random Letters</span>
							<input type="checkbox" id="panel-bc-random-letters" name="panelbcrandomletters" value="true" <?php checked('true', $bc_random_letters_enable); ?>/>
							<label for="panel-bc-random-letters"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Inline Images</span>
							<input type="checkbox" id="panel-bc-title-images" name="panelbctitleimages" value="true" <?php checked('true', $bc_title_images_enable); ?>/>
							<label for="panel-bc-title-images"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">SVG Reveal</span>
							<input type="checkbox" id="panel-bc-svg-title" name="panelbcsvgtitle" value="true" <?php checked('true', $bc_svg_title_enable); ?>/>
							<label for="panel-bc-svg-title"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Highlight Hover</span>
							<input type="checkbox" id="panel-bc-highlight-title" name="panelbchighlighttitle" value="true" <?php checked('true', $bc_highlight_title_enable); ?>/>
							<label for="panel-bc-highlight-title"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Underline Hover</span>
							<input type="checkbox" id="panel-bc-underline-title" name="panelbcunderlinetitle" value="true" <?php checked('true', $bc_underline_title_enable); ?>/>
							<label for="panel-bc-underline-title"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Swap Hover</span>
							<input type="checkbox" id="panel-bc-swap-title" name="panelbcswaptitle" value="true" <?php checked('true', $bc_swap_title_enable); ?>/>
							<label for="panel-bc-swap-title"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Scribble Reveal</span>
							<input type="checkbox" id="panel-bc-scribble-title" name="panelbcscribbletitle" value="true" <?php checked('true', $bc_scribble_title_enable); ?>/>
							<label for="panel-bc-scribble-title"></label>
						</div>
					</div>

					<div class="bc-settings__save">
						<button type="submit" class="panel-bc-submit">Save changes</button>
					</div>
				</div>
			</form>
			<?php } ?>

			<?php if ($active_tab === 'button-elements') { ?>
			<?php require_once __DIR__ . '/../../manage-button-elements.php'; ?>

			<form class="bc-settings" method="post">
				<div class="bc-settings__wrapper">

					<div class="bc-settings__title-save-wrapper">
						<div class="bc-settings__title-wrapper">
							<img class="bc-settings__icon--buttons" src="https://brickscore.io/wp-content/uploads/2023/12/plugin-dashboard-button-elements.png">
							<span class="bc-settings__title">Button elements</span>
						</div>

						<div class="bc-wrapper-toggle-all-save-submit">
							<div class="element-setting-wrapper">
								<span class="heading-element-setting">Toggle All</span>
								<input type="checkbox" id="toggle-all" name="panelbctoggleallbuttons" value="true" <?php checked('true', $bc_toggle_all_buttons_enable); ?>/>
								<label for="toggle-all"></label>
							</div>

							<div class="bc-settings__save">
								<button type="submit" class="panel-bc-submit">Save changes</button>
							</div>
						</div>
					</div>

					<div class="wrapper-element-setting-wrapper">
						<input type="hidden" name="bc-dashboard-form"/>
						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Neumorphic Button</span>
							<input type="checkbox" id="panel-bc-neumorphic-button" name="panelbcneumorphicbutton" value="true" <?php checked('true', $bc_neumorphic_button_enable); ?>/>
							<label for="panel-bc-neumorphic-button"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Prism Button</span>
							<input type="checkbox" id="panel-bc-prism-button" name="panelbcprismbutton" value="true" <?php checked('true', $bc_prism_button_enable); ?>/>
							<label for="panel-bc-prism-button"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Mask Button</span>
							<input type="checkbox" id="panel-bc-mask-button" name="panelbcmaskbutton" value="true" <?php checked('true', $bc_mask_button_enable); ?>/>
							<label for="panel-bc-mask-button"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Glowing Button</span>
							<input type="checkbox" id="panel-bc-glowing-button" name="panelbcglowingbutton" value="true" <?php checked('true', $bc_glowing_button_enable); ?>/>
							<label for="panel-bc-glowing-button"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Anyside Button</span>
							<input type="checkbox" id="panel-bc-anyside-button" name="panelbcanysidebutton" value="true" <?php checked('true', $bc_anyside_button_enable); ?>/>
							<label for="panel-bc-anyside-button"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Microbox Button</span>
							<input type="checkbox" id="panel-bc-microbox-button" name="panelbcmicroboxbutton" value="true" <?php checked('true', $bc_microbox_button_enable); ?>/>
							<label for="panel-bc-microbox-button"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Arrow Button</span>
							<input type="checkbox" id="panel-bc-arrow-button" name="panelbcarrowbutton" value="true" <?php checked('true', $bc_arrow_button_enable); ?>/>
							<label for="panel-bc-arrow-button"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Ripple Button</span>
							<input type="checkbox" id="panel-bc-ripple-button" name="panelbcripplebutton" value="true" <?php checked('true', $bc_ripple_button_enable); ?>/>
							<label for="panel-bc-ripple-button"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Crystal Button</span>
							<input type="checkbox" id="panel-bc-crystal-button" name="panelbccrystalbutton" value="true" <?php checked('true', $bc_crystal_button_enable); ?>/>
							<label for="panel-bc-crystal-button"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Layer Button</span>
							<input type="checkbox" id="panel-bc-layer-button" name="panelbclayerbutton" value="true" <?php checked('true', $bc_layer_button_enable); ?>/>
							<label for="panel-bc-layer-button"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Marquee Button</span>
							<input type="checkbox" id="panel-bc-marquee-button" name="panelbcmarqueebutton" value="true" <?php checked('true', $bc_marquee_button_enable); ?>/>
							<label for="panel-bc-marquee-button"></label>
						</div>
					</div>

					<div class="bc-settings__save">
						<button type="submit" class="panel-bc-submit">Save changes</button>
					</div>
				</div>
			</form>
			<?php } ?>

			<?php if ($active_tab === 'menu-elements') { ?>
			<?php require_once __DIR__ . '/../../manage-menu-elements.php'; ?>

			<form class="bc-settings" method="post">
				<div class="bc-settings__wrapper">

					<div class="bc-settings__title-save-wrapper">
						<div class="bc-settings__title-wrapper">
							<img class="bc-settings__icon--menus" src="https://brickscore.io/wp-content/uploads/2023/12/plugin-dashboard-menu-elements.png">
							<span class="bc-settings__title">Menu elements</span>
						</div>

						<div class="bc-wrapper-toggle-all-save-submit">
							<div class="element-setting-wrapper">
								<span class="heading-element-setting">Toggle All</span>
								<input type="checkbox" id="toggle-all" name="panelbctoggleallmenus" value="true" <?php checked('true', $bc_toggle_all_menus_enable); ?>/>
								<label for="toggle-all"></label>
							</div>

							<div class="bc-settings__save">
								<button type="submit" class="panel-bc-submit">Save changes</button>
							</div>
						</div>
					</div>

					<div class="wrapper-element-setting-wrapper">
						<input type="hidden" name="bc-dashboard-form"/>
						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Multi OffCanvas</span>
							<input type="checkbox" id="panel-bc-multioffcanvas" name="panelbcmultioffcanvas" value="true" <?php checked('true', $bc_multioffcanvas_enable); ?>/>
							<label for="panel-bc-multioffcanvas"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Expanding Menu</span>
							<input type="checkbox" id="panel-bc-expandingmenu" name="panelbcexpandingmenu" value="true" <?php checked('true', $bc_expanding_menu_enable); ?>/>
							<label for="panel-bc-expandingmenu"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Simple Menu</span>
							<input type="checkbox" id="panel-bc-simplemenu" name="panelbcsimplemenu" value="true" <?php checked('true', $bc_simple_menu_enable); ?>/>
							<label for="panel-bc-simplemenu"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Stripe megaMenu</span>
							<input type="checkbox" id="panel-bc-stripemegamenu" name="panelbcstripemegamenu" value="true" <?php checked('true', $bc_stripe_megamenu_enable); ?>/>
							<label for="panel-bc-stripemegamenu"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Sticky Header</span>
							<input type="checkbox" id="panel-bc-stickynavmenu" name="panelbcstickynavmenu" value="true" <?php checked('true', $bc_stickynav_menu_enable); ?>/>
							<label for="panel-bc-stickynavmenu"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">OffCanvas Menu</span>
							<input type="checkbox" id="panel-bc-offcanvasmenu" name="panelbcoffcanvasmenu" value="true" <?php checked('true', $bc_offcanvas_menu_enable); ?>/>
							<label for="panel-bc-offcanvasmenu"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Overlay Menu</span>
							<input type="checkbox" id="panel-bc-overlaymenu" name="panelbcoverlaymenu" value="true" <?php checked('true', $bc_overlay_menu_enable); ?>/>
							<label for="panel-bc-overlaymenu"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Morphing Nav</span>
							<input type="checkbox" id="panel-bc-morphingmenu" name="panelbcmorphingmenu" value="true" <?php checked('true', $bc_morphing_menu_enable); ?>/>
							<label for="panel-bc-morphingmenu"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Core Burguer</span>
							<input type="checkbox" id="panel-bc-coreburguer" name="panelbccoreburguer" value="true" <?php checked('true', $bc_core_burguer_enable); ?>/>
							<label for="panel-bc-coreburguer"></label>
						</div>
					</div>

					<div class="bc-settings__save">
						<button type="submit" class="panel-bc-submit">Save changes</button>
					</div>
				</div>
			</form>
			<?php } ?>

			<?php if ($active_tab === 'core-elements') { ?>
			<?php require_once __DIR__ . '/../../manage-core-elements.php'; ?>

			<form class="bc-settings" method="post">
				<div class="bc-settings__wrapper">

					<div class="bc-settings__title-save-wrapper">
						<div class="bc-settings__title-wrapper">
							<img class="bc-settings__icon--cores" src="https://brickscore.io/wp-content/uploads/2023/12/plugin-dashboard-core-elements.png">
							<span class="bc-settings__title">Core elements</span>
						</div>

						<div class="bc-wrapper-toggle-all-save-submit">
							<div class="element-setting-wrapper">
								<span class="heading-element-setting">Toggle All</span>
								<input type="checkbox" id="toggle-all" name="panelbctoggleallcores" value="true" <?php checked('true', $bc_toggle_all_cores_enable); ?>/>
								<label for="toggle-all"></label>
							</div>

							<div class="bc-settings__save">
								<button type="submit" class="panel-bc-submit">Save changes</button>
							</div>
						</div>
					</div>

					<div class="wrapper-element-setting-wrapper">
						<input type="hidden" name="bc-dashboard-form"/>
						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Codepen</span>
							<input type="checkbox" id="panel-bc-codepen" name="panelbccodepen" value="true" <?php checked('true', $bc_codepen_enable); ?>/>
							<label for="panel-bc-codepen"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Drawer</span>
							<input type="checkbox" id="panel-bc-drawer" name="panelbcdrawer" value="true" <?php checked('true', $bc_drawer_enable); ?>/>
							<label for="panel-bc-drawer"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Observer</span>
							<input type="checkbox" id="panel-bc-observer" name="panelbcobserver" value="true" <?php checked('true', $bc_observer_enable); ?>/>
							<label for="panel-bc-observer"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Bubbles</span>
							<input type="checkbox" id="panel-bc-bubbles" name="panelbcbubbles" value="true" <?php checked('true', $bc_bubbles_enable); ?>/>
							<label for="panel-bc-bubbles"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Flipbox</span>
							<input type="checkbox" id="panel-bc-flipbox" name="panelbcflipbox" value="true" <?php checked('true', $bc_flipbox_enable); ?>/>
							<label for="panel-bc-flipbox"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Motion Divider</span>
							<input type="checkbox" id="panel-bc-divider" name="panelbcdivider" value="true" <?php checked('true', $bc_divider_enable); ?>/>
							<label for="panel-bc-divider"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Spotlight</span>
							<input type="checkbox" id="panel-bc-spotlight" name="panelbcspotlight" value="true" <?php checked('true', $bc_spotlight_enable); ?>/>
							<label for="panel-bc-spotlight"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Core Tabs</span>
							<input type="checkbox" id="panel-bc-coretabs" name="panelbccoretabs" value="true" <?php checked('true', $bc_core_tabs_enable); ?>/>
							<label for="panel-bc-coretabs"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Image Hotspots</span>
							<input type="checkbox" id="panel-bc-imagehotspots" name="panelbcimagehotspots" value="true" <?php checked('true', $bc_image_hotspots_enable); ?>/>
							<label for="panel-bc-imagehotspots"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Generatorism</span>
							<input type="checkbox" id="panel-bc-generatorism" name="panelbcgeneratorism" value="true" <?php checked('true', $bc_generatorism_enable); ?>/>
							<label for="panel-bc-generatorism"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Video Sequence</span>
							<input type="checkbox" id="panel-bc-video-sequence" name="panelbcvideosequence" value="true" <?php checked('true', $bc_video_sequence_enable); ?>/>
							<label for="panel-bc-video-sequence"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Scrollbar</span>
							<input type="checkbox" id="panel-bc-scrollbar" name="panelbcscrollbar" value="true" <?php checked('true', $bc_scrollbar_enable); ?>/>
							<label for="panel-bc-scrollbar"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Cursor</span>
							<input type="checkbox" id="panel-bc-cursor" name="panelbccursor" value="true" <?php checked('true', $bc_cursor_enable); ?>/>
							<label for="panel-bc-cursor"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Marquee</span>
							<input type="checkbox" id="panel-bc-marquee" name="panelbcmarquee" value="true" <?php checked('true', $bc_marquee_enable); ?>/>
							<label for="panel-bc-marquee"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Particles</span>
							<input type="checkbox" id="panel-bc-particles" name="panelbcparticles" value="true" <?php checked('true', $bc_particles_enable); ?>/>
							<label for="panel-bc-particles"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Grainy</span>
							<input type="checkbox" id="panel-bc-grained" name="panelbcgrained" value="true" <?php checked('true', $bc_grained_enable); ?>/>
							<label for="panel-bc-grained"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Smooth Scroll</span>
							<input type="checkbox" id="panel-bc-smooth-scroll" name="panelbcsmoothscroll" value="true" <?php checked('true', $bc_smooth_scroll_enable); ?>/>
							<label for="panel-bc-smooth-scroll"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Back to Top</span>
							<input type="checkbox" id="panel-bc-back-to-top" name="panelbcbacktotop" value="true" <?php checked('true', $bc_back_to_top_enable); ?>/>
							<label for="panel-bc-back-to-top"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Sharer</span>
							<input type="checkbox" id="panel-bc-sharer" name="panelbcsharer" value="true" <?php checked('true', $bc_sharer_enable); ?>/>
							<label for="panel-bc-sharer"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Tippy</span>
							<input type="checkbox" id="panel-bc-tippy" name="panelbctippy" value="true" <?php checked('true', $bc_tippy_enable); ?>/>
							<label for="panel-bc-tippy"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Glitchy</span>
							<input type="checkbox" id="panel-bc-glitchy" name="panelbcglitchy" value="true" <?php checked('true', $bc_glitchy_enable); ?>/>
							<label for="panel-bc-glitchy"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Parallax</span>
							<input type="checkbox" id="panel-bc-parallax" name="panelbcparallax" value="true" <?php checked('true', $bc_parallax_enable); ?>/>
							<label for="panel-bc-parallax"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Dark Mode</span>
							<input type="checkbox" id="panel-bc-dark-mode" name="panelbcdarkmode" value="true" <?php checked('true', $bc_dark_mode_enable); ?>/>
							<label for="panel-bc-dark-mode"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Image Reveal</span>
							<input type="checkbox" id="panel-bc-image-reveal" name="panelbcimagereveal" value="true" <?php checked('true', $bc_image_reveal_enable); ?>/>
							<label for="panel-bc-image-reveal"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Lottie</span>
							<input type="checkbox" id="panel-bc-lottie" name="panelbclottie" value="true" <?php checked('true', $bc_lottie_enable); ?>/>
							<label for="panel-bc-lottie"></label>
						</div>
						
						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Zoom Lens</span>
							<input type="checkbox" id="panel-bc-zoom-lens" name="panelbczoomlens" value="true" <?php checked('true', $bc_zoom_lens_enable); ?>/>
							<label for="panel-bc-zoom-lens"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Expander</span>
							<input type="checkbox" id="panel-bc-expander" name="panelbcexpander" value="true" <?php checked('true', $bc_expander_enable); ?>/>
							<label for="panel-bc-expander"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Core Slider</span>
							<input type="checkbox" id="panel-bc-core-slider" name="panelbccoreslider" value="true" <?php checked('true', $bc_core_slider_enable); ?>/>
							<label for="panel-bc-core-slider"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Click & Copy</span>
							<input type="checkbox" id="panel-bc-clickandcopy" name="panelbcclickandcopy" value="true" <?php checked('true', $bc_clickandcopy_enable); ?>/>
							<label for="panel-bc-clickandcopy"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Before/After</span>
							<input type="checkbox" id="panel-bc-beforeafterimage" name="panelbcbeforeafterimage" value="true" <?php checked('true', $bc_beforeafter_image_enable); ?>/>
							<label for="panel-bc-beforeafterimage"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Parallax Hover</span>
							<input type="checkbox" id="panel-bc-3dhover" name="panelbc3dhover" value="true" <?php checked('true', $bc_3dhover_enable); ?>/>
							<label for="panel-bc-3dhover"></label>
						</div>
					</div>

					<div class="bc-settings__save">
						<button type="submit" class="panel-bc-submit">Save changes</button>
					</div>
				</div>
			</form>
			<?php } ?>

			<?php if ($active_tab === 'libraries') { ?>
			<?php require_once __DIR__ . '/../../manage-assets.php'; ?>
			<form class="bc-settings" method="post">
				<div class="bc-settings__wrapper">
					<div class="bc-settings__title-save-wrapper">
						<div class="bc-settings__title-wrapper">
							<img class="bc-settings__icon--menus" src="https://brickscore.io/wp-content/uploads/2023/12/plugin-dashboard-libraries.png">
							<span class="bc-settings__title">Libraries</span>
						</div>

						<div class="bc-settings__save">
							<button type="submit" class="panel-bc-submit">Save changes</button>
						</div>
					</div>

					<p class="bc-settings__paragraph">
						Handling libraries can be specially useful to improve performance. 
						You should disable a library if the elements you are using don´t require it or if it is already loaded by your own way or other 3rd party addons in order to manage the duplicity.<br>
						When disabling a library be sure it is already loaded and it isn´t a deprecated version otherwise elements requiring it won´t work as expected.<br><br>
						GSAP: <span style="font-style: italic">Motion Divider, Simple Menu, Expanding Menu, Unfold Reveal, Decode Reveal, Decode Hover, Blended Hover, 3D Swap Hover, Scroll Reading, Twist Title, Letter Launcher, Blade Title, Scribble Title, SVG Title, Random Letters, OffCanvas Menu, Overlay Menu, Cursor, Marquee, Image Reveal, Particles</span><br>
						ScrollTrigger: <span style="font-style: italic">Motion Divider, Simple Menu, Expanding Menu, Unfold Reveal, Decode Reveal, Decode Hover, Blended Hover, 3D Swap Hover, Scroll Reading, Twist Title, Letter Launcher, Blade Title, Scribble Title, SVG Title, Random Letters, OffCanvas Menu, Overlay Menu, Image Reveal</span><br>
						Splittext: <span style="font-style: italic">Unfold Reveal, Decode Reveal, Decode Hover, Blended Hover, 3D Swap Hover, Scroll Reading, Letter Launcher, Blade Title, Random Letters, Swap Title</span><br>
					</p>

					<div class="wrapper-element-setting-wrapper">
						<input type="hidden" name="bc-dashboard-form"/>
						<div class="element-setting-wrapper">
							<span class="heading-element-setting">GSAP</span>
							<input type="checkbox" id="panel-bc-gsap" name="panelbcgsap" value="true" <?php checked('true', $bc_gsap_enable); ?>/>
							<label for="panel-bc-gsap"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">ScrollTrigger</span>
							<input type="checkbox" id="panel-bc-scrolltrigger" name="panelbcscrolltrigger" value="true" <?php checked('true', $bc_scrolltrigger_enable); ?>/>
							<label for="panel-bc-scrolltrigger"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">SplitText</span>
							<input type="checkbox" id="panel-bc-splittext" name="panelbcsplittext" value="true" <?php checked('true', $bc_splittext_enable); ?>/>
							<label for="panel-bc-splittext"></label>
						</div>
					</div>

					<div class="bc-settings__save">
						<button type="submit" class="panel-bc-submit">Save changes</button>
					</div>
				</div>
			</form>
			<?php } ?>

			<?php if ($active_tab === 'features') { ?>
			<?php require_once __DIR__ . '/../../manage-features.php'; ?>

			<form class="bc-settings" method="post">
				<div class="bc-settings__wrapper">
					<div class="bc-settings__title-save-wrapper">
						<div class="bc-settings__title-wrapper">
							<img class="bc-settings__icon--features" src="https://brickscore.io/wp-content/uploads/2023/12/plugin-dashboard-features.png">
							<span class="bc-settings__title">Features</span>
						</div>

						<div class="bc-settings__save">
							<button type="submit" class="panel-bc-submit">Save changes</button>
						</div>
					</div>

					<div class="wrapper-element-setting-wrapper bc-features-grid">
						<input type="hidden" name="bc-dashboard-form"/>
						<div class="element-setting-wrapper bc-feature-core-animator">
							<span class="heading-element-setting">Core Animator</span>
							<input type="checkbox" id="panel-bc-core-animator" name="panelbccoreanimator" value="true" <?php checked('true', $bc_core_animator_enable); ?>/>
							<label for="panel-bc-core-animator"></label>
						</div>

						<div class="element-setting-wrapper">
							<span class="heading-element-setting">Core Animator Theme</span>
							<select id="panel-bc-core-animator-theme" name="panelbccoreanimatortheme">
								<option value="true" <?php selected('true', $bc_brickscore_animator_theme_enable); ?>>Brickscore Theme</option>
								<option value="dark" <?php selected('dark', $bc_bricksdark_animator_theme_enable); ?>>Bricks Builder Dark Theme</option>
								<option value="light" <?php selected('light', $bc_brickslight_animator_theme_enable); ?>>Bricks Builder Light Theme</option>
							</select>
						</div>
					</div>

					<div class="bc-settings__save">
						<button type="submit" class="panel-bc-submit">Save changes</button>
					</div>
				</div>
			</form>
			<?php } ?>

			<?php if ($active_tab === 'library') { ?>
			<div class="bc-settings" >
			<div class="bc-settings__wrapper">
					<div class="bc-settings__title-save-wrapper">
						<div class="bc-settings__title-wrapper">
							<img class="bc-settings__icon--menus bc-settings__icon--menus-library" src="https://brickscore.io/wp-content/uploads/2023/12/plugin-dashboard-library.png">
							<span class="bc-settings__title">Library</span>
						</div>
					</div>

					<p class="bc-settings__paragraph">
						There are two ways to import Library components into your site:
						<br><br><span class="bc-settings__heading">1. From Brickscore site</span><br><br>
						Sign in at Brickscore site and go to the Library section. Find the component you want to add to your site and click its copy button. Then go to the builder and paste it wherever you want. That's all!
						<br>
						<span style="font-style: italic">NOTE: the component class naming is based on BEM methodology. By using this method you can rename the root class before copying the component to your clipboard.</span>
						<br><br><span class="bc-settings__heading">2. As Remote Templates</span><br><br>
						To begin importing the Library components as Bricks Templates you will have to establish connection to the Library.
						<br>Go to Bricks > Settings > Templates > Remote templates and introduce the following:<br>
						<br>Name: The name you want to display for the Library at the builder. e.g: Brickscore Library
						<br>URL: https://library.brickscore.io
						<br>Password: brickscore_library<br><br>
						<img class="bc-settings__screenshot" src="https://brickscore.io/wp-content/uploads/2024/02/library-set-up.png">
						<br><br>And Save Settings. Once you establish connection to the Library, run Bricks and start importing!<br><br>
						<img class="bc-settings__screenshot" src="https://brickscore.io/wp-content/uploads/2024/02/templates-tab.png"><br><br>
						<img class="bc-settings__screenshot" src="https://brickscore.io/wp-content/uploads/2024/02/library-templates.png"><br><br>
						<span style="font-style: italic">NOTE: Once you set it up at your site you won't have to do anything more as you will receive all Library updates (new components) automatically.</span><br>
						<span style="font-style: italic">NOTE: Both methods are perfectly compatible. If you want to rename a component root class do it at Brickscore site. If you don't need to, then importing components as templates can speed up your workflow.</span>
					</p>
				</div>
			</div>

			<?php } ?>
		</div>

		<?php
	}

	/**
	 * Print the css for the form.
	 *
	 * @return void
	 */
	public function print_css() {
		?>
		<script>
			document.addEventListener('DOMContentLoaded', function () {
				var toggleAll = document.getElementById('toggle-all');
				var individualSwitches = document.querySelectorAll('.wrapper-element-setting-wrapper input[type="checkbox"]');

				toggleAll.addEventListener('change', function () {
					var isChecked = toggleAll.checked;
					individualSwitches.forEach(function (switchElement) {
						switchElement.checked = isChecked;
					});
				});
			});
		</script>
		<style>
			.bc-settings__heading{
				font-size: 18px;
				font-weight: 600;
			}
			.bc-settings__icon--menus-library{
				bottom: 0 !important;
			}
			.bc-settings__screenshot{
				width: 100%;
			}
			p{
				font-size: 14px;
			}
		</style>
		<style>
			.bc-wrapper-toggle-all-save-submit{
				display: flex;
				flex-direction: row;
				column-gap: 25px;
			}
			#wpfooter{
				display: none !important;
			}
			#wpcontent{
				padding-left: 0 !important;
			}
			#wpbody-content{
				padding-bottom: 0 !important;
			}
			#wpwrap{
				background: #1B1A1B !important;
			}
			.bc-body, .bc-body *{
				box-sizing: border-box;
				padding: 0;
				margin: 0;
			}
			.bc-body a:active, .bc-body a:focus {
				outline: 0 !important;
				border: none !important;
				-moz-outline-style: none !important;
				box-shadow: none !important;
			}
			.bc-body{
				min-height: calc(100svh - 32px);
				width: 100%;
				padding-bottom: 35px;

				background: #1B1A1B;

				display: flex;
				flex-direction: row;

				z-index: 11;
				position: relative;
				overflow: visible;
			}
			.uip-user-frame .bc-body{
				min-height: 100svh;
			}
			.bc-sidebar{
				position: fixed;
				height: fit-content;
				min-height: calc(100svh - 32px);

				display: flex;
				flex-direction: column;
				justify-content: space-between;

				padding: 27px;
			}
			.bc-sidebar__changelog-wrapper{
				all: unset;
				cursor: pointer;
				position: absolute;
				top: 27px;
				right: 27px;

				display: flex;
				align-items: center;
				column-gap: 7.5px;

				border-radius: 100px;
				padding: 10px 15px;
				background: #2B244B;

				color: #6D50FE !important;
				font-weight: 500;
			}
			.bc-sidebar__changelog-logo{
				width: 13px;
				height: 13px;
			}
			.bc-sidebar__logo-wrapper{
				display: flex;
				column-gap: 10px;
				align-items: center;

				margin-bottom: 50px;
			}
			.bc-sidebar__logo{
				width: 30px;
				height: 30px;
			}
			.bc-sidebar__logo-title{
				font-size: 16px;
				letter-spacing: 1px;
				font-weight: 500;

				color: white;
				text-transform: uppercase;

				margin: 0;
			}
			.bc-sidebar__navigation{
				display: flex;
				flex-direction: column;
			}
			.bc-sidebar__nav-item-wrapper{
				all: unset;
				cursor: pointer;
				position: relative;

				font-size: 14px;
				color: white !important;
				letter-spacing: -.25px;

				display: flex;
				column-gap: 10px;
				align-items: center;

				padding: 10px 15px;
				width: fit-content;
				border-radius: 100px;

				transition: background .3s;

				margin-left: -10px;
				margin-bottom: 5px;
			}.bc-sidebar__nav-item-wrapper:hover{background: #242424;}
			.bc-sidebar__nav-item-wrapper-active{
				background: #242424;
			}
			.bc-sidebar__nav-item-separator{
				width: 180px;
				height: 1px;

				background: #242424;

				margin-top: 10px;
				margin-bottom: 15px;
				margin-left: -15px;
			}

			.bc-license{
				white-space: nowrap;
				position: static;
				max-width: 258px;
			}
			.bc-form__wrapper{
				display: flex;

				background: #242424;
				border-radius: 100px;

				padding: 10px;
				column-gap: 5px;
				width: fit-content;

				box-shadow: 0px 0px 40px 5px rgba(0,0,0,0.1);
			}
			.bc-form__input, .label-license-deactivate-state{
				all: unset !important;

				border-radius: 100px !important;
				padding: 5px 10px !important;

				color: white !important;
				background: #1B1A1B !important;
			}.bc-form__input::placeholder{color: white !important;}
			.bc-form__wrapper .submit{
				all: unset !important;
				cursor: pointer !important;
			}
			.bc-form__wrapper .submit input{
				all: unset !important;

				border-radius: 100px !important;
				padding: 5px 10px !important;

				color: white !important;
				background: #6D50FE !important;
			}

			.bc-settings{
				flex-wrap: wrap;
				
				width: 100%;
				height: fit-content;

				display: flex;
				justify-content: center;
				
				margin: 113px 0;
			}
			.bc-settings__wrapper{
				width: 100%;
				max-width: 855px;
			}
			.bc-settings__title-save-wrapper{
				display: flex;
				justify-content: space-between;
				align-items: flex-end;

				padding-bottom: 20px;
				border-bottom: 1px solid #242424;
			}
			.bc-settings__title-wrapper{
				position: relative;
				display: flex;
				align-items: center;
				column-gap: 10px;

				font-size: 16px;
				height: fit-content;
				color: white;
			}
			.bc-settings__icon--texts{
				position: absolute;
			}
			.bc-settings__icon--buttons{
				position: absolute;
				bottom: 3px;
			}
			.bc-settings__icon--menus{
				position: absolute;
				bottom: -1px;
			}
			.bc-settings__icon--cores{
				position: absolute;
				bottom: -1px;
			}
			.bc-settings__icon--features{
				position: absolute;
			}
			.bc-settings__title{
				margin-left: 30px;
			}
			.bc-settings__save{
				all: unset !important;
				cursor: pointer !important;
			}
			.bc-settings__save button{
				all: unset !important;

				border-radius: 100px !important;
				padding: 5px 10px !important;

				color: white !important;
				background: #6D50FE !important;
			}
			.wrapper-element-setting-wrapper{
				margin: 20px 0;
				padding: 25px 35px;
				border-radius: 20px;

				display: grid;
    			grid-template-columns: 1fr 1fr 1fr 1fr;
				row-gap: 15px;
				column-gap: 35px;

				background: #242424;
			}
			.element-setting-wrapper{
				display: flex;
				justify-content: space-between;
				align-items: center;
			}
			.heading-element-setting{
				font-size: 14px;
				letter-spacing: -.25px;
				color: white;
			}
			.bc-settings__paragraph{
				color: white;
				margin-top: 20px;
			}
			.bc-features-grid{
				display: flex;
			}
			.bc-feature-core-animator{
				width: 22%;
				max-width: 175px;
			}
			.bc-features-grid .element-setting-wrapper{
				max-width: 350px;
			}
			.element-setting-wrapper{
				display: flex;
				column-gap: 20px;
			}
			.element-setting-wrapper select{
				border-radius: 100px;
				font-size: 14px !important;
				min-height: 30px !important;
			}

			@media screen and (max-width: 1600px) {
				.bc-settings__wrapper{
					max-width: unset;
					margin-right: 33px;
					margin-left: 293px;
				}
			}
			@media screen and (max-width: 1200px) {
				.wrapper-element-setting-wrapper{
					grid-template-columns: 1fr 1fr 1fr;
				}
				.bc-settings__wrapper{
					margin-left: unset;
				}
				.bc-sidebar{
					position: static;
				}
			}
			@media screen and (max-width: 1032px) {
				.bc-sidebar{
					position: static;
				}
				.bc-license{
					margin-left: calc(50% - 258px/2);
					margin-top: 20px;
					margin-bottom: 10px;
				}
				.bc-body{
					flex-direction: column;
				}
				.bc-settings {
					margin: 45px 0;
				}
				.bc-settings__wrapper{
					margin: 0 30px;
				}
				.bc-sidebar{
					min-height: unset;
				}
				.bc-sidebar__nav-item-wrapper{
					width: calc(100% - 10px);
				}
				.bc-sidebar__nav-item-separator{
					width: calc(100% + 30px);
				}
				.bc-sidebar__changelog-wrapper{
					right: 25px;
				}
				.bc-sidebar__logo-wrapper{
					margin-left: -10px;
				}
				.wrapper-element-setting-wrapper{
					grid-template-columns: 1fr 1fr;
				}
				.bc-features-grid{
					flex-direction: column;
				}
				.bc-feature-core-animator{
					width: 175px;
				}
			}
			@media screen and (max-width: 497px) {
				.wrapper-element-setting-wrapper{
					grid-template-columns: 1fr;
				}
				.bc-settings__title-save-wrapper{
					align-items: flex-start;
					flex-direction: column;
					row-gap: 15px;
				}
				.bc-wrapper-toggle-all-save-submit{
					display: flex;
					flex-direction: row;
					column-gap: 25px;
				}
			}

			/*Switch*/
			.element-setting-wrapper input[type=checkbox]{
				position: absolute !important;
				height: 0 !important;
				width: 0 !important;
				visibility: hidden !important;
				margin: 0 !important;
				padding: 0 !important;
				min-width: 0 !important;
				min-height: 0 !important;
				max-width: 0 !important;
				max-height: 0 !important;
				border: 0 !important;
			}
			.element-setting-wrapper label {
				cursor: pointer;
				text-indent: -9999px;
				min-width: 35px;
				min-height: 20px;
				background: #000;
				display: block;
				border-radius: 100px;
				position: relative;
				margin: 0 !important;
			}
			.element-setting-wrapper label:after {
				content: '';
				position: absolute;
				top: 2px;
				left: 2px;
				width: 16px;
				height: 16px;
				background: #fff;
				border-radius: 90px;
				transition: 0.2s ease-in-out;
			}
			.element-setting-wrapper input:checked + label {
				background: #6c51fe;
			}
			.element-setting-wrapper input:checked + label:after {
				left: calc(100% - 2px);
				transform: translateX(-100%);
			}
		</style>
		<?php
	}

	/**
	 * Get the activation.
	 *
	 * @return Object|false
	 */
	public function get_activation() {
		return (object)array("id"=>"this_is_my_id", "license_key"=>"this_is_my_license_key");
		$activation = false;
		if ( $this->activation_id ) {
			$activation = $this->client->activation()->get( $this->activation_id );
			if ( is_wp_error( $activation ) ) {
				$this->add_error( 'deactivaed', $this->client->__( 'Your license has been deactivated for this site.', 'surecart' ) );
				$this->clear_options();
			}
		}
		return $activation;
	}

	/**
	 * License form submit
	 */
	public function license_form_submit() {
		// only if we are submitting.
		if ( ! isset( $_POST['submit'] ) ) {
			return;
		}

		// Check nonce.
		if ( ! isset( $_POST['_nonce'], $_POST['_action'] ) ) {
			$this->add_error( 'missing_info', $this->client->__( 'Please add all information' ) );
			return;
		}

		// Cerify nonce.
		if ( ! wp_verify_nonce( $_POST['_nonce'], $this->client->name ) ) {
			$this->add_error( 'unauthorized', $this->client->__( "You don't have permission to manage licenses." ) );
			return;
		}

		// handle activation.
		if ( 'activate' === $_POST['_action'] ) {
			$activated = $this->client->license()->activate( sanitize_text_field( $_POST['license_key'] ) );
			if ( is_wp_error( $activated ) ) {
				$this->add_error( $activated->get_error_code(), $activated->get_error_message() );
				return;
			}

			if ( ! empty( $this->menu_args['activated_redirect'] ) ) {
				$this->redirect( $this->menu_args['activated_redirect'] );
				exit;
			}

			return $this->add_success( 'activated', $this->client->__( 'This site was successfully activated.', 'surecart' ) );
		}

		// handle deactivation.
		if ( 'deactivate' === $_POST['_action'] ) {
			$deactivated = $this->client->license()->deactivate( sanitize_text_field( $_POST['activation_id'] ) );
			if ( is_wp_error( $deactivated ) ) {
				$this->add_error( $deactivated->get_error_code(), $deactivated->get_error_message() );
			}

			if ( ! empty( $this->menu_args['deactivated_redirect'] ) ) {
				$this->redirect( $this->menu_args['deactivated_redirect'] );
				exit;
			}

			return $this->add_success( 'deactivated', $this->client->__( 'This site was successfully deactivated.', 'surecart' ) );
		}
	}

	/**
	 * Redirect to a url client-side.
	 * We need to do this to avoid "headers already sent" messages.
	 *
	 * @param string $url Url to redirect.
	 *
	 * @return void
	 */
	public function redirect( $url ) {
		?>
		<div class="spinner is-active"></div>
		<script>
			window.location.assign("<?php echo esc_url( $url ); ?>");
		</script>
		<?php
	}

	/**
	 * Add a notice.
	 *
	 * @param string $code Notice code.
	 * @param string $message Notice message.
	 * @param string $type Notice type.
	 *
	 * @return void
	 */
	public function add_notice( $code, $message, $type = 'info' ) {
		add_settings_error(
			$this->name . '_license_options', // matches what we registered in `register_setting.
			$code, // the error code.
			$message,
			$type
		);
	}

	/**
	 * Add an error.
	 *
	 * @param string $code Error code.
	 * @param string $message Error message.
	 *
	 * @return void
	 */
	public function add_error( $code, $message ) {
		$this->add_notice( $code, $message, 'error' );
	}

	/**
	 * Add an success message
	 *
	 * @param string $code Success code.
	 * @param string $message Success message.
	 *
	 * @return void
	 */
	public function add_success( $code, $message ) {
		$this->add_notice( $code, $message, 'success' );
	}

	/**
	 * Set an option.
	 *
	 * @param string $name Name of option.
	 *
	 * @return mixed
	 */
	public function __get( $name ) {
		return $this->get_option( 'sc_' . $name );
	}

	/**
	 * Set an option
	 *
	 * @param string $name Name of option.
	 * @param mixed  $value Value.
	 *
	 * @return bool
	 */
	public function __set( $name, $value ) {
		return $this->set_option( 'sc_' . $name, $value );
	}
}
